import { compose, replace } from 'ramda'

/**
 * Decodes a path according to https://tools.ietf.org/html/rfc6901 by replacing special symbols
 *
 * @function
 * @param {string} path - A valid path
 * @returns {string} result - The decoded path with properly replaced characters
 * @example
 *
 * decodePath('/foo~1bar') // '/foo/bar'
 * decodePath('/foo ~0/bar~1/2') // '/foo~/bar/2'
 */
const decodePath = compose(replace(/\s/g, ''), replace(/~0/g, '~'), replace(/~1/g, '/'))

export default decodePath
